@@ -39,7 +39,7 @@ class NERTask(LightningModule):
         labels = inputs["labels"]
         acc = accuracy(preds, labels, ignore_index=NER_PAD_ID)
         self.log("train_loss", outputs.loss, prog_bar=False, logger=True, on_step=True, on_epoch=False)
-        self.log("train_acc", acc, prog_bar=False, logger=True, on_step=True, on_epoch=False)
+        self.log("train_acc", acc, prog_bar=True, logger=True, on_step=True, on_epoch=False)
         return outputs.loss
 
     def validation_step(self, inputs, batch_idx):
